From 8f900054fac96ffee411240d0d2dc6e12feba5d9 Mon Sep 17 00:00:00 2001
From: Satish MR <satishmr123@gmail.com>
Date: Sun, 8 Jul 2012 14:08:06 +0530
Subject: [PATCH] HLS: Check for Segment in all hls streams.
 If Playback thread does not find a segment it has to check the segments available in other bitrate hls streams.

current behaveour is: GetSegment() function will check for available segment ONLY in 1st hls stream.
This patch makes GetSegment function to check available segment in all hls streams.
---
 modules/stream_filter/httplive.c |   24 +++++++++++++++++++-----
 1 files changed, 19 insertions(+), 5 deletions(-)

diff --git a/modules/stream_filter/httplive.c b/modules/stream_filter/httplive.c
index 77ae5f2..fe47bab 100644
--- a/modules/stream_filter/httplive.c
+++ b/modules/stream_filter/httplive.c
@@ -2055,20 +2055,23 @@ static segment_t *GetSegment(stream_t *s)
     }
 
     /* Was the HLS stream changed to another bitrate? */
+	msg_Err(s, "warning : required segment (%d) not found in current hls stream. check in other hls streams", p_sys->playback.segment);
     segment = NULL;
-    for (int i_stream = 0; i_stream < vlc_array_count(p_sys->hls_stream); i_stream++)
+	int count = vlc_array_count(p_sys->hls_stream);
+    for (int i_stream = 0; i_stream < count; i_stream++)
     {
         /* Is the next segment ready */
         hls_stream_t *hls = hls_Get(p_sys->hls_stream, i_stream);
-        if (hls == NULL)
-            return NULL;
+        if (hls == NULL) {
+			continue; //Check for all hls streams
+		}
 
         vlc_mutex_lock(&hls->lock);
         segment = segment_GetSegment(hls, p_sys->playback.segment);
         if (segment == NULL)
         {
             vlc_mutex_unlock(&hls->lock);
-            break;
+            continue;//Check for all hls streams
         }
 
         vlc_mutex_lock(&p_sys->download.lock_wait);
@@ -2093,7 +2096,18 @@ static segment_t *GetSegment(stream_t *s)
             break;
     }
     /* */
-    return NULL;
+	if ((segment == NULL) || (segment->data == NULL)) {
+		msg_Err(s, "No downloaded segment (%d) found in any hls streams.; return NULL", p_sys->playback.segment);
+		return NULL;
+	}
+
+    vlc_mutex_lock(&p_sys->download.lock_wait);
+    int i_segment = p_sys->download.segment;
+    vlc_mutex_unlock(&p_sys->download.lock_wait);
+	if (p_sys->playback.segment >= i_segment) {
+		msg_Err(s, "Playback counter %d is more than Download Counter %d; return null", p_sys->playback.segment, i_segment);
+		return NULL;
+	}
 
 check:
     /* sanity check */
-- 
1.7.0.4

